@@ -19,10 +19,14 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-import collections
 import sys
 import warnings
 
+if sys.version_info[0] == 2:
+    import collections as abc
+else:
+    from collections import abc
+
 from gi.repository import GObject
 from .._ossighelper import wakeup_on_signal, register_sigint_fallback
 from .._gtktemplate import Template
@@ -77,7 +81,7 @@ __all__.append('_construct_target_list')
 
 def _extract_handler_and_args(obj_or_map, handler_name):
     handler = None
-    if isinstance(obj_or_map, collections.Mapping):
+    if isinstance(obj_or_map, abc.Mapping):
         handler = obj_or_map.get(handler_name, None)
     else:
         handler = getattr(obj_or_map, handler_name, None)
@@ -86,7 +90,7 @@ def _extract_handler_and_args(obj_or_map, handler_name):
         raise AttributeError('Handler %s not found' % handler_name)
 
     args = ()
-    if isinstance(handler, collections.Sequence):
+    if isinstance(handler, abc.Sequence):
         if len(handler) == 0:
             raise TypeError("Handler %s tuple can not be empty" % handler)
         args = handler[1:]
@@ -118,10 +122,25 @@ def _builder_connect_callback(builder, gobj, signal_name, handler_name, connect_
             gobj.connect(signal_name, handler, *args)
 
 
+class _FreezeNotifyManager(object):
+    def __init__(self, obj):
+        self.obj = obj
+
+    def __enter__(self):
+        pass
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.obj.thaw_child_notify()
+
+
 class Widget(Gtk.Widget):
 
     translate_coordinates = strip_boolean_result(Gtk.Widget.translate_coordinates)
 
+    def freeze_child_notify(self):
+        super(Widget, self).freeze_child_notify()
+        return _FreezeNotifyManager(self)
+
     def drag_dest_set_target_list(self, target_list):
         if (target_list is not None) and (not isinstance(target_list, Gtk.TargetList)):
             target_list = Gtk.TargetList.new(_construct_target_list(target_list))
@@ -393,7 +412,7 @@ if Gtk._version in ("2.0", "3.0"):
             if not isinstance(buffer, string_types):
                 raise TypeError('buffer must be a string')
 
-            length = len(buffer.encode('UTF-8'))
+            length = _get_utf8_length(buffer)
 
             return Gtk.UIManager.add_ui_from_string(self, buffer, length)
 
@@ -443,6 +462,14 @@ MenuItem = override(MenuItem)
 __all__.append('MenuItem')
 
 
+def _get_utf8_length(string):
+    if not isinstance(string, string_types):
+        raise TypeError('must be a string')
+    if not isinstance(string, bytes):
+        string = string.encode("utf-8")
+    return len(string)
+
+
 class Builder(Gtk.Builder):
     def connect_signals(self, obj_or_map):
         """Connect signals specified by this builder to a name, handler mapping.
@@ -462,7 +489,7 @@ class Builder(Gtk.Builder):
         if not isinstance(buffer, string_types):
             raise TypeError('buffer must be a string')
 
-        length = len(buffer)
+        length = _get_utf8_length(buffer)
 
         return Gtk.Builder.add_from_string(self, buffer, length)
 
@@ -470,7 +497,7 @@ class Builder(Gtk.Builder):
         if not isinstance(buffer, string_types):
             raise TypeError('buffer must be a string')
 
-        length = len(buffer)
+        length = _get_utf8_length(buffer)
 
         return Gtk.Builder.add_objects_from_string(self, buffer, length, object_ids)
 
@@ -1255,6 +1282,8 @@ class TreeStore(Gtk.TreeStore, TreeModel, TreeSortable):
             if sibling is None:
                 position = -1
             else:
+                if parent is None:
+                    parent = self.iter_parent(sibling)
                 position = self.get_path(sibling).get_indices()[-1]
             return self._do_insert(parent, position, row)
 
@@ -1265,6 +1294,8 @@ class TreeStore(Gtk.TreeStore, TreeModel, TreeSortable):
             if sibling is None:
                 position = 0
             else:
+                if parent is None:
+                    parent = self.iter_parent(sibling)
                 position = self.get_path(sibling).get_indices()[-1] + 1
             return self._do_insert(parent, position, row)
 
