@@ -26,15 +26,6 @@ Pango = get_introspection_module('Pango')
 __all__ = []
 
 
-class Context(Pango.Context):
-
-    def get_metrics(self, desc, language=None):
-        return super(Context, self).get_metrics(desc, language)
-
-Context = override(Context)
-__all__.append('Context')
-
-
 class FontDescription(Pango.FontDescription):
 
     def __new__(cls, string=None):
@@ -43,6 +34,10 @@ class FontDescription(Pango.FontDescription):
         else:
             return Pango.FontDescription.__new__(cls)
 
+    def __init__(self, *args, **kwargs):
+        return super(FontDescription, self).__init__()
+
+
 FontDescription = override(FontDescription)
 __all__.append('FontDescription')
 
@@ -55,5 +50,6 @@ class Layout(Pango.Layout):
     def set_markup(self, text, length=-1):
         super(Layout, self).set_markup(text, length)
 
+
 Layout = override(Layout)
 __all__.append('Layout')
