@@ -34,17 +34,16 @@ typedef struct {
 
 extern PyTypeObject PyGIBoxed_Type;
 
-PyObject * _pygi_boxed_new (PyTypeObject *type,
-                            gpointer      boxed,
-                            gboolean      free_on_dealloc,
-                            gsize         allocated_slice);
+PyObject * pygi_boxed_new (PyTypeObject *type,
+                           gpointer      boxed,
+                           gboolean      free_on_dealloc,
+                           gsize         allocated_slice);
 
-void * _pygi_boxed_alloc (GIBaseInfo *info,
-                          gsize *size);
+void * pygi_boxed_alloc (GIBaseInfo *info, gsize *size);
 
-void _pygi_boxed_copy_in_place  (PyGIBoxed *self);
+void pygi_boxed_copy_in_place  (PyGIBoxed *self);
 
-void _pygi_boxed_register_types (PyObject *m);
+int pygi_boxed_register_types (PyObject *m);
 
 G_END_DECLS
 
