@@ -589,8 +589,16 @@ class TestPropertyBindings(unittest.TestCase):
         self.assertEqual(self.source.int_prop, 10)
         self.assertEqual(self.target.int_prop, 1)
 
-        # An already unbound BindingWeakRef will raise if unbind is attempted a second time.
-        self.assertRaises(ValueError, binding.unbind)
+        glib_version = (GLib.MAJOR_VERSION, GLib.MINOR_VERSION, GLib.MICRO_VERSION)
+
+        # calling unbind() on an already unbound binding
+        if glib_version >= (2, 57, 3):
+            # Fixed in newer glib:
+            # https://gitlab.gnome.org/GNOME/glib/merge_requests/244
+            for i in range(10):
+                binding.unbind()
+        else:
+            self.assertRaises(ValueError, binding.unbind)
 
     def test_reference_counts(self):
         self.assertEqual(self.source.__grefcount__, 1)
@@ -714,13 +722,16 @@ class TestGValue(unittest.TestCase):
         self.assertEqual(testhelper.value_array_get_nth_type(value, 1), GObject.TYPE_STRING)
 
     def test_value_array_append_gvalue(self):
-        arr = GObject.ValueArray.new(0)
-        arr.append(GObject.Value(GObject.TYPE_UINT, 0xffffffff))
-        arr.append(GObject.Value(GObject.TYPE_STRING, 'foo_bar'))
-        self.assertEqual(arr.get_nth(0), 0xffffffff)
-        self.assertEqual(arr.get_nth(1), 'foo_bar')
-        self.assertEqual(testhelper.value_array_get_nth_type(arr, 0), GObject.TYPE_UINT)
-        self.assertEqual(testhelper.value_array_get_nth_type(arr, 1), GObject.TYPE_STRING)
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', DeprecationWarning)
+
+            arr = GObject.ValueArray.new(0)
+            arr.append(GObject.Value(GObject.TYPE_UINT, 0xffffffff))
+            arr.append(GObject.Value(GObject.TYPE_STRING, 'foo_bar'))
+            self.assertEqual(arr.get_nth(0), 0xffffffff)
+            self.assertEqual(arr.get_nth(1), 'foo_bar')
+            self.assertEqual(testhelper.value_array_get_nth_type(arr, 0), GObject.TYPE_UINT)
+            self.assertEqual(testhelper.value_array_get_nth_type(arr, 1), GObject.TYPE_STRING)
 
     def test_gerror_boxing(self):
         error = GLib.Error('test message', domain='mydomain', code=42)
